=== modified file 'bzrlib/selftest/__init__.py'
--- bzrlib/selftest/__init__.py	2005-10-17 06:28:03 +0000
+++ bzrlib/selftest/__init__.py	2005-10-17 06:57:11 +0000
@@ -439,7 +439,7 @@
         logging.info('an info message')
         warning('something looks dodgy...')
         logging.debug('hello, test is running')
-        assert 0
+        ## assert 0
 
 
 def filter_suite_by_re(suite, pattern):

=== modified file 'bzrlib/selftest/testtestament.py'
--- bzrlib/selftest/testtestament.py	2005-10-13 03:23:22 +0000
+++ bzrlib/selftest/testtestament.py	2005-10-17 06:57:11 +0000
@@ -102,6 +102,19 @@
         t = Testament.from_revision(self.b, 'test@user-3')
         self.assertEqualDiff(t.as_text(), REV_3_TESTAMENT)
 
+    def test_testament_revprops(self):
+        """Testament to revision with extra properties"""
+        props = dict(flavor='sour cherry\ncream cheese',
+                     size='medium')
+        self.b.commit(message='revision with properties',
+                      timestamp=1129025493,
+                      timezone=36000,
+                      rev_id='test@user-3',
+                      committer='test@user',
+                      revprops=props)
+        t = Testament.from_revision(self.b, 'test@user-3')
+        self.assertEqualDiff(t.as_text(), REV_PROPS_TESTAMENT)
+                    
 
 REV_1_TESTAMENT = """\
 bazaar-ng testament version 1
@@ -146,6 +159,29 @@
 """ % sha(REV_2_TESTAMENT).hexdigest()
 
 
+REV_PROPS_TESTAMENT = """\
+bazaar-ng testament version 1
+revision-id: test@user-3
+committer: test@user
+timestamp: 1129025493
+timezone: 36000
+parents:
+  test@user-2
+message:
+  revision with properties
+inventory:
+  file hello hello-id 34dd0ac19a24bf80c4d33b5c8960196e8d8d1f73
+  directory src src-id
+  file src/foo.c foo.c-id a2a049c20f908ae31b231d98779eb63c66448f24
+properties:
+  flavor:
+    sour cherry
+    cream cheese
+  size:
+    medium
+"""
+
+
 REV_3_TESTAMENT = """\
 bazaar-ng testament version 1
 revision-id: test@user-3

=== modified file 'bzrlib/testament.py'
--- bzrlib/testament.py	2005-10-14 04:23:13 +0000
+++ bzrlib/testament.py	2005-10-17 06:57:11 +0000
@@ -69,6 +69,7 @@
 # TODO: Perhaps these should just be different formats in which inventories/
 # revisions can be serialized.
 
+from copy import copy
 from cStringIO import StringIO
 import string
 from sha import sha
@@ -98,6 +99,7 @@
         t.message = rev.message
         t.parent_ids = rev.parent_ids[:]
         t.inventory = branch.get_inventory(revision_id)
+        t.revprops = copy(rev.properties)
         assert not contains_whitespace(t.revision_id)
         assert not contains_linebreaks(t.committer)
         return t
@@ -127,6 +129,7 @@
         a('inventory:\n')
         for path, ie in self.inventory.iter_entries():
             a(self._entry_to_line(path, ie))
+        r.extend(self._revprops_to_lines())
         if __debug__:
             for l in r:
                 assert isinstance(l, str), \
@@ -165,3 +168,17 @@
                 'sha1: %s\n'
                 % (self.revision_id, s.hexdigest()))
 
+    def _revprops_to_lines(self):
+        """Pack up revision properties."""
+        if not self.revprops:
+            return []
+        r = ['properties:\n']
+        for name, value in sorted(self.revprops.items()):
+            assert isinstance(name, str)
+            assert not contains_whitespace(name)
+            r.append('  %s:\n' % name)
+            for line in value.splitlines():
+                if not isinstance(line, str):
+                    line = line.encode('utf-8')
+                r.append('    %s\n' % line)
+        return r

